==> nextcloud-25.0.7.tgz: nextcloud/apps/photos/l10n/pl.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Link publiczny",
    "Photos" : "Zdjęcia",
    "Your memories under your control" : "Twoje wspomnienia pod kontrolą",
    "All media" : "Wszystkie media",
    "Videos" : "Filmy",
    "Albums" : "Albumy",
    "Collaborative albums" : "Albumy wspólne",
    "People" : "Osoby",
    "Folders" : "Katalogi",
    "Favorites" : "Ulubione",
    "On this day" : "W tym dniu",
    "Shared with you" : "Udostępnione Tobie",
    "Tags" : "Etykiety",
    "Places" : "Miejsca",
    "Map" : "Mapa",
    "Photos settings" : "Ustawienia Zdjęć",
    "Mark selection as favorite" : "Oznacz wybrane jako ulubione",
    "Add selection to favorites" : "Dodaj wybrane do ulubionych",
    "Remove selection from favorites" : "Usuń wybrane z ulubionych",
    "Name of the album" : "Nazwa albumu",
    "Location of the album" : "Lokalizacja albumu",
    "Go back to the previous view." : "Wróć do poprzedniego widoku.",
    "Back" : "Poprzednia",
    "Go to the add collaborators view." : "Przejdź do widoku dodawania współpracowników.",
    "Add collaborators" : "Dodaj współpracowników",
    "Save." : "Zapisz.",
    "Create the album." : "Utwórz album.",
    "Save" : "Zapisz",
    "Create album" : "Utwórz album",
    "Back to the new album form." : "Powrót do nowej formy albumu.",
    "Add to Album" : "Dodaj do albumu",
    "Add selection to album {albumName}" : "Dodaj wybór do albumu {albumName}",
    "Create a new album." : "Utwórz nowy album.",
    "Create new album" : "Utwórz nowy album",
    "New album" : "Nowy album",
    "_%n item_::_%n photos and videos_" : ["%n pozycja","%n pozycje","%n pozycji","%n zdjęć i filmów"],
    "_Share with %n user_::_Share with %n users_" : ["Udostępnij %n użytkownikowi","Udostępnij %n użytkownikom","Udostępnij %n użytkownikom","Udostępnij %n użytkownikom"],
    "Add people or groups who can edit your album" : "Dodaj osoby lub grupy, które mogą edytować Twój album",
    "Search for collaborators" : "Szukaj współpracowników",
    "Search people or groups" : "Wyszukaj osoby lub grupy",
    "Add {collaboratorLabel} to the collaborators list" : "Dodaj {collaboratorLabel} do listy współpracowników",
    "No collaborators available" : "Brak dostępnych współpracowników",
    "Remove {collaboratorLabel} from the collaborators list" : "Usuń {collaboratorLabel} z listy współpracowników",
    "Copy the public link" : "Kopiuj link publiczny",
    "Public link copied!" : "Skopiowano link publiczny!",
    "Copy public link" : "Kopiuj link publiczny",
    "Delete the public link" : "Usuń link publiczny",
    "Share via public link" : "Udostępnij przez link publiczny",
    "Failed to fetch collaborators list." : "Nie udało się pobrać listy współpracowników.",
    "Failed to fetch album." : "Nie udało się pobrać albumu.",
    "Failed to update album." : "Nie udało się zaktualizować albumu.",
    "This collection does not exist" : "Ta kolekcja nie istnieje",
    "An error occurred" : "Wystąpił błąd",
    "_%n photos_::_%n photos_" : ["%n zdjęcie","%n zdjęcia","%n zdjęć","%n zdjęć"],
    "Select image {imageName}" : "Wybierz obraz {imageName}",
    "The file is in the favorites" : "Plik znajduje się w ulubionych",
    "Open the full size \"{name}\" image" : "Otwórz obraz \"{name}\" w pełnym rozmiarze",
    "There are no photos or videos yet!" : "Nie ma jeszcze zdjęć ani filmów!",
    "Add to {destination}" : "Dodaj do {destination}",
    "Open the \"{name}\" sub-directory" : "Otwórz podkatalog \"{name}\"",
    "Back to {folder}" : "Powrót do {folder}",
    "Share this folder" : "Udostępnij ten katalog",
    "_{years} year ago_::_{years} years ago_" : ["{years} rok temu","{years} lata temu","{years} lat temu","{years} lat temu"],
    "Enable squared photos view" : "Włącz zdjęcia w widoku kwadratowym",
    "Default Photos upload and Albums location" : "Domyślna lokalizacja przesyłania zdjęć i albumów",
    "Select the default location for your media" : "Wybierz domyślną lokalizację swoich multimediów",
    "Invalid location selected" : "Wybrano nieprawidłową lokalizację",
    "View" : "Podgląd",
    "Photos directory" : "Katalog zdjęć",
    "_%n photo_::_%n photos_" : ["%n zdjęcie","%n zdjęcia","%n zdjęć","%n zdjęć"],
    "Manage collaborators for this album" : "Zarządzaj współpracownikami tego albumu",
    "Open actions menu" : "Otwórz menu akcji",
    "Edit album details" : "Edytuj szczegóły albumu",
    "Download all files in album" : "Pobierz wszystkie pliki z albumu",
    "Delete album" : "Usuń album",
    "Download selected files" : "Pobierz wybrane pliki",
    "Remove selection from album" : "Usuń wybrane z albumu",
    "This album does not have any photos or videos yet!" : "W tym albumie nie ma jeszcze żadnych zdjęć ani filmów!",
    "Add photos to this album" : "Dodaj zdjęcia do tego albumu",
    "Add photos to the album" : "Dodaj zdjęcia do albumu",
    "Manage collaborators" : "Zarządzaj współpracownikami",
    "Save collaborators for this album." : "Zapisywanie współpracowników dla tego albumu.",
    "Cover photo for album {albumName}" : "Zdjęcie na okładkę albumu {albumName}",
    "There is no album yet!" : "Nie ma jeszcze albumu!",
    "This person could not be found" : "Nie można znaleźć osoby",
    "Rename person" : "Zmień nazwę osoby",
    "Merge with different person" : "Połącz z inną osobą",
    "Download selected photos" : "Pobierz wybrane zdjęcia",
    "Favorite" : "Ulubiony",
    "Remove from favorites" : "Usuń z ulubionych",
    "Remove person" : "Usuń osobę",
    "Name of this person" : "Nazwa tej osoby",
    "Merge person" : "Połącz osobę",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Przenieś zdjęcie do innej osoby","Przenieś zdjęcia do innej osoby","Przenieś zdjęcia do innej osoby","Przenieś zdjęcia do innej osoby"],
    "_Remove photo from person_::_Remove photos from person_" : ["Usuń zdjęcie od osoby","Usuń zdjęcia od osoby","Usuń zdjęcia od osoby","Usuń zdjęcia od osoby"],
    "This might take some time depending on the size of your photo library." : "Może to zająć trochę czasu, w zależności od rozmiaru biblioteki zdjęć.",
    "Recognized people will show up here" : "Rozpoznane osoby pojawią się tutaj",
    "This folder does not exist" : "Ten katalog nie istnieje",
    "Loading folders …" : "Ładowanie katalogów …",
    "No photos in here" : "Brak zdjęć",
    "This place does not have any photos or videos yet!" : "To miejsce nie ma jeszcze żadnych zdjęć ani filmów!",
    "Add photos to this place" : "Dodaj zdjęcia do tego miejsca",
    "Cover photo for place {placeName}" : "Zdjęcie na okładkę {placeName}",
    "There is no place yet!" : "Nie ma jeszcze miejsca!",
    "Failed to fetch albums list." : "Nie udało się pobrać listy albumów.",
    "Shared by" : "Udostępnione przez",
    "Shared albums" : "Udostępnione albumy",
    "Cover photo for shared album {albumName}." : "Zdjęcie na okładkę albumu udostępnionego {albumName}.",
    "Back to tags overview" : "Powrót do przeglądania etykiet",
    "No photos with this tag yet" : "Nie ma jeszcze zdjęć z tą etykietą",
    "No tags yet" : "Brak etykiet",
    "Photos with tags will show up here" : "Zdjęcia z etykietami pojawią się tutaj",
    "Popular tags" : "Popularne etykiety",
    "Add" : "Dodaj",
    "Create a new album" : "Utwórz nowy album",
    "Add selection to an album" : "Dodaj wybrane do albumu",
    "Add to album" : "Dodaj do albumu",
    "Delete selection" : "Usuń wybrane",
    "No photos or videos in here" : "Nie ma tu zdjęć ani filmów",
    "Failed to fetch collection." : "Nie udało się pobrać kolekcji.",
    "Failed to fetch collections list." : "Nie udało się pobrać listę kolekcji.",
    "Failed to fetch faces list." : "Nie udało się pobrać listy twarzy.",
    "All your media" : "Wszystkie Twoje media",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Albumy udostępnione",
    "Shared album {title}" : "Udostępniony album {title}",
    "Public album {title}" : "Publiczny album {title}",
    "Tagged photos" : "Oznaczone zdjęcia",
    "Tagged photo {title}" : "Zdjęcie oznaczone etykietą {title}",
    "{title}'s face" : "Twarz {title}",
    "Failed to create {albumName}." : "Nie udało się utworzyć {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Nie udało się zmienić nazwy {currentAlbumName} na {newAlbumName}.",
    "Failed to rename {oldName} to {faceName}." : "Nie udało się zmienić nazwy {oldName} na {faceName}.",
    "Failed to delete {faceName}." : "Nie udało się usunąć {faceName}.",
    "Failed to delete {fileId}." : "Nie udało się usunąć {fileId}.",
    "Failed to delete {fileName}." : "Nie udało się usunąć {fileName}.",
    "Failed to set favorite state for {fileId}." : "Nie udało się ustawić statusu ulubionego dla {fileId}.",
    "Failed to set favorite state for {fileName}." : "Nie udało się ustawić statusu ulubionego dla {fileName}.",
    "Your photos" : "Zdjęcia",
    "Your videos" : "Twoje filmy",
    "Your folders" : "Twoje katalogi",
    "Locations" : "Lokalizacje",
    "Settings" : "Ustawienia"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-25.0.8.tgz: nextcloud/apps/photos/l10n/pl.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Link publiczny",
    "Photos" : "Zdjęcia",
    "Your memories under your control" : "Twoje wspomnienia pod kontrolą",
    "All media" : "Wszystkie media",
    "Videos" : "Filmy",
    "Albums" : "Albumy",
    "Collaborative albums" : "Albumy wspólne",
    "People" : "Osoby",
    "Folders" : "Katalogi",
    "Favorites" : "Ulubione",
    "On this day" : "W tym dniu",
    "Shared with you" : "Udostępnione Tobie",
    "Tags" : "Etykiety",
    "Places" : "Miejsca",
    "Map" : "Mapa",
    "Photos settings" : "Ustawienia Zdjęć",
    "Mark selection as favorite" : "Oznacz wybrane jako ulubione",
    "Add selection to favorites" : "Dodaj wybrane do ulubionych",
    "Remove selection from favorites" : "Usuń wybrane z ulubionych",
    "Name of the album" : "Nazwa albumu",
    "Location of the album" : "Lokalizacja albumu",
    "Go back to the previous view." : "Wróć do poprzedniego widoku.",
    "Back" : "Poprzednia",
    "Go to the add collaborators view." : "Przejdź do widoku dodawania współpracowników.",
    "Add collaborators" : "Dodaj współpracowników",
    "Save." : "Zapisz.",
    "Create the album." : "Utwórz album.",
    "Save" : "Zapisz",
    "Create album" : "Utwórz album",
    "Back to the new album form." : "Powrót do nowej formy albumu.",
    "Add to Album" : "Dodaj do albumu",
    "Add selection to album {albumName}" : "Dodaj wybór do albumu {albumName}",
    "Shared by" : "Udostępnione przez",
    "Create a new album." : "Utwórz nowy album.",
    "Create new album" : "Utwórz nowy album",
    "New album" : "Nowy album",
    "_%n item_::_%n photos and videos_" : ["%n pozycja","%n pozycje","%n pozycji","%n zdjęć i filmów"],
    "Add people or groups who can edit your album" : "Dodaj osoby lub grupy, które mogą edytować Twój album",
    "Search people or groups" : "Wyszukaj osoby lub grupy",
    "No recommendations. Start typing." : "Brak rekomendacji. Możesz napisać.",
    "Group" : "Grupa",
    "Remove {collaboratorLabel} from the collaborators list" : "Usuń {collaboratorLabel} z listy współpracowników",
    "Copy the public link" : "Kopiuj link publiczny",
    "Public link copied!" : "Skopiowano link publiczny!",
    "Copy public link" : "Kopiuj link publiczny",
    "Delete the public link" : "Usuń link publiczny",
    "Share via public link" : "Udostępnij przez link publiczny",
    "Failed to fetch collaborators list." : "Nie udało się pobrać listy współpracowników.",
    "Failed to update album." : "Nie udało się zaktualizować albumu.",
    "This collection does not exist" : "Ta kolekcja nie istnieje",
    "An error occurred" : "Wystąpił błąd",
    "_%n photos_::_%n photos_" : ["%n zdjęcie","%n zdjęcia","%n zdjęć","%n zdjęć"],
    "Select image {imageName}" : "Wybierz obraz {imageName}",
    "The file is in the favorites" : "Plik znajduje się w ulubionych",
    "Open the full size \"{name}\" image" : "Otwórz obraz \"{name}\" w pełnym rozmiarze",
    "There are no photos or videos yet!" : "Nie ma jeszcze zdjęć ani filmów!",
    "Add to {destination}" : "Dodaj do {destination}",
    "Open the \"{name}\" sub-directory" : "Otwórz podkatalog \"{name}\"",
    "Back to {folder}" : "Powrót do {folder}",
    "Share this folder" : "Udostępnij ten katalog",
    "_{years} year ago_::_{years} years ago_" : ["{years} rok temu","{years} lata temu","{years} lat temu","{years} lat temu"],
    "Enable squared photos view" : "Włącz zdjęcia w widoku kwadratowym",
    "Default Photos upload and Albums location" : "Domyślna lokalizacja przesyłania zdjęć i albumów",
    "Select the default location for your media" : "Wybierz domyślną lokalizację swoich multimediów",
    "Invalid location selected" : "Wybrano nieprawidłową lokalizację",
    "View" : "Podgląd",
    "Photos directory" : "Katalog zdjęć",
    "_%n photo_::_%n photos_" : ["%n zdjęcie","%n zdjęcia","%n zdjęć","%n zdjęć"],
    "Manage collaborators for this album" : "Zarządzaj współpracownikami tego albumu",
    "Open actions menu" : "Otwórz menu akcji",
    "Edit album details" : "Edytuj szczegóły albumu",
    "Download all files in album" : "Pobierz wszystkie pliki z albumu",
    "Delete album" : "Usuń album",
    "Download selected files" : "Pobierz wybrane pliki",
    "Remove selection from album" : "Usuń wybrane z albumu",
    "This album does not have any photos or videos yet!" : "W tym albumie nie ma jeszcze żadnych zdjęć ani filmów!",
    "Add photos to this album" : "Dodaj zdjęcia do tego albumu",
    "Manage collaborators" : "Zarządzaj współpracownikami",
    "Save collaborators for this album." : "Zapisywanie współpracowników dla tego albumu.",
    "Cover photo for album {albumName}" : "Zdjęcie na okładkę albumu {albumName}",
    "There is no album yet!" : "Nie ma jeszcze albumu!",
    "This person could not be found" : "Nie można znaleźć osoby",
    "Rename person" : "Zmień nazwę osoby",
    "Merge with different person" : "Połącz z inną osobą",
    "Download selected photos" : "Pobierz wybrane zdjęcia",
    "Favorite" : "Ulubiony",
    "Remove from favorites" : "Usuń z ulubionych",
    "Remove person" : "Usuń osobę",
    "Name of this person" : "Nazwa tej osoby",
    "Merge person" : "Połącz osobę",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Przenieś zdjęcie do innej osoby","Przenieś zdjęcia do innej osoby","Przenieś zdjęcia do innej osoby","Przenieś zdjęcia do innej osoby"],
    "_Remove photo from person_::_Remove photos from person_" : ["Usuń zdjęcie od osoby","Usuń zdjęcia od osoby","Usuń zdjęcia od osoby","Usuń zdjęcia od osoby"],
    "This might take some time depending on the size of your photo library." : "Może to zająć trochę czasu, w zależności od rozmiaru biblioteki zdjęć.",
    "Recognized people will show up here" : "Rozpoznane osoby pojawią się tutaj",
    "This folder does not exist" : "Ten katalog nie istnieje",
    "Loading folders …" : "Ładowanie katalogów …",
    "No photos in here" : "Brak zdjęć",
    "This place does not have any photos or videos yet!" : "To miejsce nie ma jeszcze żadnych zdjęć ani filmów!",
    "Add photos to this place" : "Dodaj zdjęcia do tego miejsca",
    "Cover photo for place {placeName}" : "Zdjęcie na okładkę {placeName}",
    "There is no place yet!" : "Nie ma jeszcze miejsca!",
    "Cover photo for shared album {albumName}." : "Zdjęcie na okładkę albumu udostępnionego {albumName}.",
    "Back to tags overview" : "Powrót do przeglądania etykiet",
    "No photos with this tag yet" : "Nie ma jeszcze zdjęć z tą etykietą",
    "No tags yet" : "Brak etykiet",
    "Photos with tags will show up here" : "Zdjęcia z etykietami pojawią się tutaj",
    "Popular tags" : "Popularne etykiety",
    "Add" : "Dodaj",
    "Create a new album" : "Utwórz nowy album",
    "Add selection to an album" : "Dodaj wybrane do albumu",
    "Add to album" : "Dodaj do albumu",
    "Delete selection" : "Usuń wybrane",
    "No photos or videos in here" : "Nie ma tu zdjęć ani filmów",
    "Failed to fetch collection." : "Nie udało się pobrać kolekcji.",
    "Failed to fetch collections list." : "Nie udało się pobrać listę kolekcji.",
    "Failed to fetch faces list." : "Nie udało się pobrać listy twarzy.",
    "All your media" : "Wszystkie Twoje media",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Albumy udostępnione",
    "Shared album {title}" : "Udostępniony album {title}",
    "Public album {title}" : "Publiczny album {title}",
    "Tagged photos" : "Oznaczone zdjęcia",
    "Tagged photo {title}" : "Zdjęcie oznaczone etykietą {title}",
    "{title}'s face" : "Twarz {title}",
    "Failed to rename {oldName} to {faceName}." : "Nie udało się zmienić nazwy {oldName} na {faceName}.",
    "Failed to delete {faceName}." : "Nie udało się usunąć {faceName}.",
    "Failed to delete {fileId}." : "Nie udało się usunąć {fileId}.",
    "Failed to delete {fileName}." : "Nie udało się usunąć {fileName}.",
    "Failed to set favorite state for {fileId}." : "Nie udało się ustawić statusu ulubionego dla {fileId}.",
    "Failed to set favorite state for {fileName}." : "Nie udało się ustawić statusu ulubionego dla {fileName}.",
    "Locations" : "Lokalizacje",
    "_Share with %n user_::_Share with %n users_" : ["Udostępnij %n użytkownikowi","Udostępnij %n użytkownikom","Udostępnij %n użytkownikom","Udostępnij %n użytkownikom"],
    "Search for collaborators" : "Szukaj współpracowników",
    "Add {collaboratorLabel} to the collaborators list" : "Dodaj {collaboratorLabel} do listy współpracowników",
    "No collaborators available" : "Brak dostępnych współpracowników",
    "Failed to fetch album." : "Nie udało się pobrać albumu.",
    "Add photos to the album" : "Dodaj zdjęcia do albumu",
    "Failed to fetch albums list." : "Nie udało się pobrać listy albumów.",
    "Shared albums" : "Udostępnione albumy",
    "Failed to create {albumName}." : "Nie udało się utworzyć {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Nie udało się zmienić nazwy {currentAlbumName} na {newAlbumName}."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
